summaryrefslogtreecommitdiff
path: root/util/unicode/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'util/unicode/main.cpp')
-rw-r--r--util/unicode/main.cpp42
1 files changed, 22 insertions, 20 deletions
diff --git a/util/unicode/main.cpp b/util/unicode/main.cpp
index 9a2123f3ca..a8f8086003 100644
--- a/util/unicode/main.cpp
+++ b/util/unicode/main.cpp
@@ -1,17 +1,19 @@
/****************************************************************************
**
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Contact: http://www.qt-project.org/legal
**
** This file is part of the utils of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Commercial License Agreement provided with the
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -21,8 +23,8 @@
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
@@ -33,8 +35,7 @@
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
+**
** $QT_END_LICENSE$
**
****************************************************************************/
@@ -2468,18 +2469,20 @@ int main(int, char **)
QByteArray header =
"/****************************************************************************\n"
"**\n"
- "** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).\n"
+ "** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).\n"
"** All rights reserved.\n"
- "** Contact: Nokia Corporation (qt-info@nokia.com)\n"
+ "** Contact: http://www.qt-project.org/legal\n"
"**\n"
"** This file is part of the QtCore module of the Qt Toolkit.\n"
"**\n"
"** $QT_BEGIN_LICENSE:LGPL$\n"
- "** Commercial Usage\n"
- "** Licensees holding valid Qt Commercial licenses may use this file in\n"
- "** accordance with the Qt Commercial License Agreement provided with the\n"
+ "** Commercial License Usage\n"
+ "** Licensees holding valid commercial Qt licenses may use this file in\n"
+ "** accordance with the commercial license agreement provided with the\n"
"** Software or, alternatively, in accordance with the terms contained in\n"
- "** a written agreement between you and Nokia.\n"
+ "** a written agreement between you and Digia. For licensing terms and\n"
+ "** conditions see http://qt.digia.com/licensing. For further information\n"
+ "** use the contact form at http://qt.digia.com/contact-us.\n"
"**\n"
"** GNU Lesser General Public License Usage\n"
"** Alternatively, this file may be used under the terms of the GNU Lesser\n"
@@ -2489,8 +2492,8 @@ int main(int, char **)
"** ensure the GNU Lesser General Public License version 2.1 requirements\n"
"** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.\n"
"**\n"
- "** In addition, as a special exception, Nokia gives you certain additional\n"
- "** rights. These rights are described in the Nokia Qt LGPL Exception\n"
+ "** In addition, as a special exception, Digia gives you certain additional\n"
+ "** rights. These rights are described in the Digia Qt LGPL Exception\n"
"** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.\n"
"**\n"
"** GNU General Public License Usage\n"
@@ -2501,8 +2504,7 @@ int main(int, char **)
"** ensure the GNU General Public License version 3.0 requirements will be\n"
"** met: http://www.gnu.org/copyleft/gpl.html.\n"
"**\n"
- "** If you have questions regarding the use of this file, please contact\n"
- "** Nokia at qt-info@nokia.com.\n"
+ "**\n"
"** $QT_END_LICENSE$\n"
"**\n"
"****************************************************************************/\n\n"
@@ -1,17 +1,19 @@
** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Nokia.
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
+** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
@@ -21,8 +23,8 @@
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights. These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**